/* eslint-disable react/jsx-no-leaked-render */
/* eslint-disable jsx-a11y/no-static-element-interactions */
import React, { useState } from 'react';
import { SlidersIcon, InputsIcon, PaletteIcon } from './icon.js';
import { usePicker } from '../context.js';
import EyeDropper from './EyeDropper.js';
import { config } from '../constants.js';
import AdvancedControls from './AdvancedControls.js';
import ComparibleColors from './ComparibleColors.js';
import GradientControls from './GradientControls.js';
import { colorTypeBtnStyles, controlBtnStyles, modalBtnStyles } from '../styles/styles.js';
const { defaultColor, defaultGradient } = config;
const ColorTypeBtns = ({ hideColorTypeBtns, isGradient, setSolid, setGradient, locales, }) => {
    const { defaultStyles } = usePicker();
    if (hideColorTypeBtns) {
        return React.createElement("div", { style: { width: 1 } });
    }
    else {
        return (React.createElement("div", { style: defaultStyles.controlBtnWrapper },
            React.createElement("div", { onClick: setSolid, id: "rbgcp-solid-btn", style: colorTypeBtnStyles(!isGradient, defaultStyles) }, locales?.CONTROLS?.SOLID),
            React.createElement("div", { onClick: setGradient, id: "rbgcp-gradient-btn", style: colorTypeBtnStyles(isGradient || false, defaultStyles) }, locales?.CONTROLS?.GRADIENT)));
    }
};
const InputTypeDropdown = ({ openInputType, setOpenInputType, }) => {
    const { inputType, setInputType, defaultStyles } = usePicker();
    const vTrans = openInputType
        ? 'visibility 0ms linear'
        : 'visibility 100ms linear 150ms';
    const zTrans = openInputType
        ? 'z-index 0ms linear'
        : 'z-index 100ms linear 150ms';
    const oTrans = openInputType
        ? 'opacity 120ms linear'
        : 'opacity 150ms linear 50ms';
    const handleInputType = (e, val) => {
        if (openInputType) {
            e.stopPropagation();
            setInputType(val);
            setOpenInputType(false);
        }
    };
    return (React.createElement("div", { style: {
            visibility: openInputType ? 'visible' : 'hidden',
            zIndex: openInputType ? '' : -100,
            opacity: openInputType ? 1 : 0,
            transition: `${oTrans}, ${vTrans}, ${zTrans}`,
            ...defaultStyles.rbgcpColorModelDropdown,
        } },
        React.createElement("div", { onClick: (e) => handleInputType(e, 'rgb'), style: modalBtnStyles(inputType === 'rgb', defaultStyles) }, "RGB"),
        React.createElement("div", { onClick: (e) => handleInputType(e, 'hsl'), style: modalBtnStyles(inputType === 'hsl', defaultStyles) }, "HSL"),
        React.createElement("div", { onClick: (e) => handleInputType(e, 'hsv'), style: modalBtnStyles(inputType === 'hsv', defaultStyles) }, "HSV"),
        React.createElement("div", { onClick: (e) => handleInputType(e, 'cmyk'), style: modalBtnStyles(inputType === 'cmyk', defaultStyles) }, "CMYK")));
};
const Controls = ({ locales, hideEyeDrop = false, hideAdvancedSliders = false, hideColorGuide = false, hideInputType = false, hideColorTypeBtns = false, hideGradientControls = false, hideGradientType = false, hideGradientAngle = false, hideGradientStop = false, }) => {
    const { onChange, isGradient, handleChange, previous, defaultStyles } = usePicker();
    const [openComparibles, setOpenComparibles] = useState(false);
    const [openInputType, setOpenInputType] = useState(false);
    const [openAdvanced, setOpenAdvanced] = useState(false);
    const noTools = hideEyeDrop && hideAdvancedSliders && hideColorGuide && hideInputType;
    const solidColor = previous?.color || defaultColor;
    const gradientColor = previous?.gradient || defaultGradient;
    const setSolid = () => {
        onChange(solidColor);
    };
    const setGradient = () => {
        onChange(gradientColor);
    };
    const allRightControlsHidden = hideEyeDrop && hideAdvancedSliders && hideColorGuide && hideInputType;
    const allControlsHidden = allRightControlsHidden && hideColorTypeBtns;
    if (allControlsHidden) {
        if (isGradient && !hideGradientControls) {
            return (React.createElement(GradientControls, { hideGradientType: hideGradientType, hideGradientAngle: hideGradientAngle, hideGradientStop: hideGradientStop }));
        }
        else {
            return null;
        }
    }
    else {
        return (React.createElement("div", { style: { paddingTop: 12, paddingBottom: 4 } },
            React.createElement("div", { style: {
                    width: '100%',
                    display: 'flex',
                    alignItems: 'center',
                    justifyContent: 'space-between',
                } },
                React.createElement(ColorTypeBtns, { hideColorTypeBtns: hideColorTypeBtns, setGradient: setGradient, isGradient: isGradient, setSolid: setSolid, locales: locales }),
                !allRightControlsHidden && (React.createElement("div", { style: {
                        display: noTools ? 'none' : '',
                        ...defaultStyles.rbgcpControlBtnWrapper,
                    } },
                    !hideEyeDrop && React.createElement(EyeDropper, { onSelect: handleChange }),
                    React.createElement("div", { id: "rbgcp-advanced-btn", onClick: () => setOpenAdvanced(!openAdvanced), style: {
                            display: hideAdvancedSliders ? 'none' : 'flex',
                            ...controlBtnStyles(openAdvanced, defaultStyles),
                        } },
                        React.createElement(SlidersIcon, { color: openAdvanced ? '#568CF5' : '' })),
                    React.createElement("div", { id: "rbgcp-comparibles-btn", style: {
                            display: hideColorGuide ? 'none' : 'flex',
                            ...controlBtnStyles(openComparibles, defaultStyles),
                        }, onClick: () => setOpenComparibles(!openComparibles) },
                        React.createElement(PaletteIcon, { color: openComparibles ? '#568CF5' : '' })),
                    React.createElement("div", { id: "rbgcp-color-model-btn", onClick: () => setOpenInputType(!openInputType), style: {
                            display: hideInputType ? 'none' : 'flex',
                            ...controlBtnStyles(openInputType, defaultStyles),
                        } },
                        React.createElement(InputsIcon, { color: openInputType ? '#568CF5' : '' }),
                        React.createElement(InputTypeDropdown, { openInputType: openInputType, setOpenInputType: setOpenInputType }))))),
            !hideAdvancedSliders && (React.createElement(AdvancedControls, { openAdvanced: openAdvanced })),
            !hideColorGuide && (React.createElement(ComparibleColors, { openComparibles: openComparibles })),
            isGradient && !hideGradientControls && (React.createElement(GradientControls, { hideGradientType: hideGradientType, hideGradientAngle: hideGradientAngle, hideGradientStop: hideGradientStop }))));
    }
};
export default Controls;
