import React from 'react';
import { usePicker } from '../context.js';
import { formatInputValues, low, high } from '../utils/formatters.js';
import { controlBtnStyles } from '../styles/styles.js';
import TrashIcon, { LinearIcon, RadialIcon, DegreesIcon, StopIcon, } from './icon.js';
const GradientType = () => {
    const { gradientType, onChange, value, defaultStyles } = usePicker();
    const isLinear = gradientType === 'linear-gradient';
    const isRadial = gradientType === 'radial-gradient';
    const handleLinear = () => {
        const remaining = value.split(/,(.+)/)[1];
        onChange(`linear-gradient(90deg, ${remaining}`);
    };
    const handleRadial = () => {
        const remaining = value.split(/,(.+)/)[1];
        onChange(`radial-gradient(circle, ${remaining}`);
    };
    return (React.createElement("div", { style: defaultStyles.rbgcpControlBtnWrapper },
        React.createElement("div", { onClick: handleLinear, id: "rbgcp-linear-btn", style: { ...defaultStyles.rbgcpControlBtn, ...(isLinear && defaultStyles.rbgcpControlBtnSelected) }, tabIndex: 0, role: "button", onKeyDown: () => {
                return;
            } },
            React.createElement(LinearIcon, { color: isLinear ? '#568CF5' : '' })),
        React.createElement("div", { onClick: handleRadial, id: "rbgcp-radial-btn", style: { ...defaultStyles.rbgcpControlBtn, ...(isRadial && defaultStyles.rbgcpControlBtnSelected) }, tabIndex: 0, role: "button", onKeyDown: () => {
                return;
            } },
            React.createElement(RadialIcon, { color: isRadial ? '#568CF5' : '' }))));
};
const StopPicker = () => {
    const { currentLeft, handleGradient, currentColor, defaultStyles } = usePicker();
    const handleMove = (newVal) => {
        handleGradient(currentColor, formatInputValues(parseInt(newVal), 0, 100));
    };
    return (React.createElement("div", { style: {
            ...defaultStyles.rbgcpControlBtnWrapper,
            ...defaultStyles.rbgcpControlInputWrap,
            ...defaultStyles.rbgcpStopInputWrap,
            paddingLeft: 8,
        } },
        React.createElement(StopIcon, null),
        React.createElement("input", { value: currentLeft, id: "rbgcp-stop-input", onChange: (e) => handleMove(e.target.value), style: { ...defaultStyles.rbgcpControlInput, ...defaultStyles.rbgcpStopInput } })));
};
const DegreePicker = () => {
    const { degrees, onChange, value, defaultStyles } = usePicker();
    const handleDegrees = (e) => {
        const newValue = formatInputValues(e.target.value, 0, 360);
        const remaining = value.split(/,(.+)/)[1];
        onChange(`linear-gradient(${newValue || 0}deg, ${remaining}`);
    };
    return (React.createElement("div", { style: {
            ...defaultStyles.rbgcpControlBtnWrapper,
            ...defaultStyles.rbgcpControlInputWrap,
            ...defaultStyles.rbgcpDegreeInputWrap,
        } },
        React.createElement(DegreesIcon, null),
        React.createElement("input", { value: degrees, id: "rbgcp-degree-input", onChange: (e) => handleDegrees(e), style: {
                ...defaultStyles.rbgcpControlInput,
                ...defaultStyles.rbgcpDegreeInput,
            } }),
        React.createElement("div", { style: {
                position: 'absolute',
                right: degrees > 99 ? 0 : degrees < 10 ? 7 : 3,
                top: 1,
                fontWeight: 400,
                fontSize: 13,
                ...defaultStyles.rbgcpDegreeIcon,
            } }, "\u00B0")));
};
const DeleteBtn = () => {
    const { colors, selectedColor, createGradientStr, defaultStyles } = usePicker();
    const deletePoint = () => {
        if (colors?.length > 2) {
            const formatted = colors?.map((fc, i) => ({
                ...fc,
                value: i === selectedColor - 1 ? high(fc) : low(fc),
            }));
            const remaining = formatted?.filter((_, i) => i !== selectedColor);
            createGradientStr(remaining);
        }
    };
    return (React.createElement("div", { onClick: deletePoint, style: { ...controlBtnStyles(false, defaultStyles), width: 28 }, id: "rbgcp-point-delete-btn", tabIndex: 0, role: "button", onKeyDown: () => {
            return;
        } },
        React.createElement(TrashIcon, null)));
};
const GradientControls = ({ hideGradientType, hideGradientAngle, hideGradientStop, }) => {
    const { gradientType, defaultStyles } = usePicker();
    return (React.createElement("div", { style: {
            marginTop: 12,
            marginBottom: -4,
            justifyContent: 'space-between',
            paddingLeft: hideGradientType ? 4 : 0,
            ...defaultStyles.rbgcpControlBtnWrapper,
        }, id: "rbgcp-gradient-controls-wrap" },
        !hideGradientType && React.createElement(GradientType, null),
        React.createElement("div", { style: { width: 53 } }, !hideGradientAngle && gradientType === 'linear-gradient' && (React.createElement(DegreePicker, null))),
        !hideGradientStop && React.createElement(StopPicker, null),
        React.createElement(DeleteBtn, null)));
};
export default GradientControls;
